@@ -30,7 +30,7 @@ async fn main() -> AtomicResult<()> {
             SubCommand::with_name("export")
                 .about("Create a JSON-AD backup of the store.")
                 .arg(Arg::with_name("path")
-                    .help("Where the file should be saved. Defaults to `~/.config/atomic/backups/{current_date}.jsonld`.")
+                    .help("Where the file should be saved. Defaults to `~/.config/atomic/backups/{current_date}.json`.")
                     .required(false)
                 )
         )
@@ -42,6 +42,10 @@ async fn main() -> AtomicResult<()> {
                     .required(true)
                 )
         )
+        .subcommand(
+            SubCommand::with_name("index")
+                .about("Rebuilds the index, and starts the server.")
+        )
         .get_matches();
 
     // Enable all logging
@@ -60,6 +64,8 @@ async fn main() -> AtomicResult<()> {
             panic!("Error during appstate setup. {}", e)
         }
     };
+    let appstate_clone = appstate.clone();
+    let mut build_index = !appstate_clone.store.has_index();
 
     match matches.subcommand_name() {
         Some("export") => {
@@ -67,7 +73,7 @@ async fn main() -> AtomicResult<()> {
                 Some(p) => std::path::Path::new(p).to_path_buf(),
                 None => {
                     let date = chrono::Local::now().to_rfc3339();
-                    let pathstr = format!("backups/{}.jsonld", date);
+                    let pathstr = format!("backups/{}.json", date);
                     let mut pt = config.config_dir;
                     pt.push(&pathstr);
                     pt
@@ -95,6 +101,9 @@ async fn main() -> AtomicResult<()> {
         Some("run") => {
             // continue, start server
         }
+        Some("index") => {
+            build_index = true;
+        }
         Some(unkown) => {
             panic!("Unkown command: {}", unkown);
         }
@@ -103,6 +112,19 @@ async fn main() -> AtomicResult<()> {
         },
     };
 
+    // Start other async processes
+    #[cfg(feature = "desktop")]
+    tray_icon::tray_icon_process(config.clone());
+
+    actix_web::rt::spawn(async move {
+        if build_index {
+            log::warn!("Building index... This could take a while, expect worse performance until 'Building index finished'");
+            appstate_clone.store.clear_index().expect("Failed to clear index");
+            appstate_clone.store.build_index(true).expect("Failed to build index");
+            log::info!("Building index finished!");
+        }
+    });
+
     let server = HttpServer::new(move || {
         let data = web::Data::new(Mutex::new(appstate.clone()));
         // Allow requests from other domains
@@ -125,8 +147,7 @@ async fn main() -> AtomicResult<()> {
             )
     });
 
-    #[cfg(feature = "desktop")]
-    tray_icon::tray_icon_process(config.clone());
+    let message = format!("{}\n\nVisit {}\n\n", BANNER, config.local_base_url);
 
     if config.https {
         // If there is no certificate file, or the certs are too old, start HTTPS initialization
@@ -137,7 +158,7 @@ async fn main() -> AtomicResult<()> {
         let https_config = crate::https::get_https_config(&config)
             .expect("HTTPS TLS Configuration with Let's Encrypt failed.");
         let endpoint = format!("{}:{}", config.ip, config.port_https);
-        println!("{}\n\nvisit https://{}\n\n", BANNER, &endpoint);
+        println!("{}", message);
         server
             .bind_rustls(&endpoint, https_config)
             .expect(&*format!("Cannot bind to endpoint {}", &endpoint))
@@ -146,7 +167,7 @@ async fn main() -> AtomicResult<()> {
         Ok(())
     } else {
         let endpoint = format!("{}:{}", config.ip, config.port);
-        println!("{}\n\n Visit http://{}\n\n", BANNER, &endpoint);
+        println!("{}", message);
         server
             .bind(&format!("{}:{}", config.ip, config.port))
             .expect(&*format!("Cannot bind to endpoint {}", &endpoint))
